@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: EphySidebar.cpp,v 1.6 2006/03/19 20:48:13 jframeau Exp $
  */
 
 #include "mozilla-config.h"
@@ -27,6 +27,10 @@
 #include <nsCRT.h>
 #include <nsIProgrammingLanguage.h>
 
+#ifdef HAVE_GECKO_1_9
+#include <nsIClassInfoImpl.h>
+#endif
+
 #undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
 #define MOZILLA_INTERNAL_API 1
@@ -102,14 +106,3 @@ EphySidebar::AddSearchEngine (const char *aEngineURL,
 
 	return NS_OK;
 }
-
-#ifdef HAVE_GECKO_1_8_1
-
-/* void addMicrosummaryGenerator (in string generatorURL); */
-NS_IMETHODIMP
-EphySidebar::AddMicrosummaryGenerator (const char *generatorURL)
-{
-	return NS_ERROR_NOT_IMPLEMENTED;
-}
-
-#endif /* HAVE_GECKO_1_8_1 */
