@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.41.2.2 2006/05/15 18:32:49 chpe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.42 2006/04/17 14:22:21 chpe Exp $
  */
 
 /*
@@ -228,7 +228,7 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 	
 	dialog = gtk_dialog_new_with_buttons ("", gparent,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
-					      (char *) NULL);
+					      NULL);
 	if (gparent)
 	{
 		gtk_window_group_add_window (ephy_gui_ensure_window_group (gparent),
@@ -498,7 +498,7 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK,
 					      GTK_RESPONSE_OK,
-					      (char *) NULL);
+					      NULL);
 
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
@@ -563,7 +563,7 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 					      NSSDIALOG_RESPONSE_VIEW_CERT,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      _("_Trust CA"),	GTK_RESPONSE_ACCEPT,
-					      (char *) NULL);
+					      NULL);
 
 	if (gparent)
 	{
@@ -646,7 +646,7 @@ GtkNSSDialogs::NotifyCACertExists (nsIInterfaceRequestor *ctx)
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK,
 					      GTK_RESPONSE_OK,
-					      (char *) NULL);
+					      NULL);
 
 	if (gparent)
 	{
@@ -778,7 +778,7 @@ GtkNSSDialogs::SetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL,
 					      GTK_RESPONSE_CANCEL,
-					      (char *) NULL);
+					      NULL);
 
 	if (gparent)
 	{
@@ -901,7 +901,7 @@ GtkNSSDialogs::GetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      _("I_mport Certificate"), GTK_RESPONSE_OK,
-					      (char *) NULL);
+					      NULL);
 
 	if (gparent)
 	{
@@ -1003,7 +1003,7 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 					      GTK_WINDOW (gparent),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
-					      (char *) NULL);
+					      NULL);
 
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Certificate Revocation List Imported"));
@@ -1282,7 +1282,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 						     0, "Certificate",
 						     renderer,
 						     "text", 0,
-						     (char *) NULL);
+						     NULL);
 
 	GtkTreeSelection *select = gtk_tree_view_get_selection (GTK_TREE_VIEW (chain_tree_view));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
@@ -1303,7 +1303,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 						     0, "Certificate Field",
 						     renderer,
 						     "text", 0,
-						     (char *) NULL);
+						     NULL);
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (field_tree_view));
 	gtk_tree_selection_set_mode (select, GTK_SELECTION_SINGLE);
