@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.125.2.1 2006/04/10 18:52:29 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.126 2006/04/10 18:52:05 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -1010,7 +1010,7 @@ mozilla_embed_net_state_all_cb (GtkMozEmbed *embed, const char *aURI,
 
 	update_load_state (membed, state);
 	
-	g_signal_emit_by_name (membed, "ge_net_state", aURI, estate);
+	g_signal_emit_by_name (membed, "ge_net_state", aURI, /* FIXME: (gulong) */ estate);
 }
 
 static gboolean
