@@ -17,7 +17,7 @@
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
-*  $Id: mozilla-notifiers.cpp,v 1.64 2006/01/16 23:51:40 chpe Exp $
+*  $Id: mozilla-notifiers.cpp,v 1.67 2006/04/02 20:04:17 chpe Exp $
 */
 
 #include "mozilla-config.h"
@@ -50,6 +50,8 @@
 /* define to migrate epiphany 1.0 font preferences */
 #define MIGRATE_PIXEL_SIZE
 
+#define MAX_FONT_SIZE	128
+
 /* Keeps the list of the notifiers we installed for mozilla prefs */
 /* to be able to remove them when exiting */
 static GList *notifiers = NULL;
@@ -213,7 +215,6 @@ transform_image_animation_mode (GConfEntry *gcentry,
 {
 	GConfValue *gcvalue;
 	const char *mode;
-	int mozilla_mode = 0;
 
 	gcvalue = gconf_entry_get_value (gcentry);
 	if (gcvalue == NULL ||
@@ -222,21 +223,13 @@ transform_image_animation_mode (GConfEntry *gcentry,
 	mode = gconf_value_get_string (gcvalue);
 	if (mode == NULL) return FALSE;
 
-	if (strcmp (mode, "normal") == 0)
+	if (strcmp (mode, "disabled") == 0)
 	{
-		mozilla_mode = 0;
-	}
-	else if (strcmp (mode, "once") == 0)
-	{
-		mozilla_mode = 1;
-	}
-	else if (strcmp (mode, "disabled") == 0)
-	{
-		mozilla_mode = 2;
+		mode = "none";
 	}
 
-	g_value_init (value, G_TYPE_INT);
-	g_value_set_int (value, mozilla_mode);
+	g_value_init (value, G_TYPE_STRING);
+	g_value_set_string (value, mode);
 
 	return TRUE;
 }
@@ -497,7 +490,7 @@ mozilla_pref_set (const char *pref,
 			rv = gPrefBranch->GetIntPref (pref, &old_value);
 			if (NS_FAILED (rv) || old_value != new_value)
 			{
-				rv = gPrefBranch->SetIntPref (pref, g_value_get_int (value));
+				rv = gPrefBranch->SetIntPref (pref, new_value);
 			}
 			break;
 		}
@@ -565,13 +558,11 @@ notify_cb (GConfClient *client,
 	}
 }
 
-static guint
-mozilla_notifier_add_internal (const char *gconf_key,
-			       GConfClientNotifyFunc notify_func,
-			       const char *mozilla_pref,
-			       PrefValueTransformFunc func,
-			       gpointer user_data,
-			       GFreeFunc free_data_func)
+extern "C" guint
+mozilla_notifier_add (const char *gconf_key,
+		      const char *mozilla_pref,
+		      PrefValueTransformFunc func,
+		      gpointer user_data)
 {
 	GConfClient *client;
 	PrefData *data;
@@ -593,8 +584,8 @@ mozilla_notifier_add_internal (const char *gconf_key,
 	data->user_data = user_data;
 
 	cnxn_id = gconf_client_notify_add (client, gconf_key,
-					   notify_func,
-					   data, free_data_func,
+					   (GConfClientNotifyFunc) notify_cb,
+					   data, (GFreeFunc) free_pref_data,
 					   &error);
 	if (eel_gconf_handle_error (&error))
 	{
@@ -614,20 +605,6 @@ mozilla_notifier_add_internal (const char *gconf_key,
 	return cnxn_id;
 }
 
-extern "C" guint
-mozilla_notifier_add (const char *gconf_key,
-		      const char *mozilla_pref,
-		      PrefValueTransformFunc func,
-		      gpointer user_data)
-{
-	return mozilla_notifier_add_internal (gconf_key,
-					      (GConfClientNotifyFunc) notify_cb,
-					      mozilla_pref,
-					      func,
-					      user_data,
-					      (GFreeFunc) free_pref_data);
-}
-
 static int
 find_data (const PrefData *a,
 	   gconstpointer idptr)
@@ -715,15 +692,22 @@ parse_pango_font (const char *font,
 	PangoFontMask mask = (PangoFontMask) (PANGO_FONT_MASK_FAMILY | PANGO_FONT_MASK_SIZE);
 
 	PangoFontDescription *desc = pango_font_description_from_string (font);
-	if (desc == NULL ||
-	    (pango_font_description_get_set_fields (desc) & mask) != mask)
+	if (desc == NULL) return FALSE;
+
+	if ((pango_font_description_get_set_fields (desc) & mask) != mask)
 	{
+		pango_font_description_free (desc);
 		return FALSE;
 	}
-					
+				
 	*size = PANGO_PIXELS (pango_font_description_get_size (desc));
 	*name = g_strdup (pango_font_description_get_family (desc));
 
+	pango_font_description_free (desc);
+
+	LOG ("Parsed pango font description '%s' -> name:%s, size:%d",
+	     font, *name ? *name : "-", *size);
+
 	return *name != NULL && *size > 0;
 }
 
@@ -734,7 +718,6 @@ typedef struct
 	char **font_size_prefs;
 	char *font_name;
 	int font_size;
-	guint is_set : 1;
 } DesktopFontData;
 
 static gboolean
@@ -798,7 +781,7 @@ transform_font_size (GConfEntry *gcentry,
 		size = gconf_value_get_int (gcvalue);
 	}
 
-	if (size <= 0) return FALSE;
+	if (size <= 0 || size > MAX_FONT_SIZE) return FALSE;
 
 	g_value_init (value, G_TYPE_INT);
 	g_value_set_int (value, size);
@@ -824,17 +807,17 @@ notify_desktop_font_cb (GConfClient *client,
 		LOG ("Desktop font %s -> name=%s, size=%d", 
 		     gconf_entry_get_key (gcentry), name, size);
 
+		g_free (data->font_name);
 		data->font_name = name;
 		data->font_size = size;
-		data->is_set = TRUE;
 	}
 	else
 	{
 		g_free (name);
+
 		g_free (data->font_name);
 		data->font_name = NULL;
 		data->font_size = 0;
-		data->is_set = FALSE;
 	}
 
 	for (i = 0; data->font_name_prefs[i] != NULL; ++i)
@@ -921,6 +904,8 @@ mozilla_font_notifiers_init (void)
 	const EphyFontsLanguageInfo *font_languages;
 	guint n_font_languages, i;
 
+	eel_gconf_monitor_add ("/desktop/gnome/interface");
+
 	font_languages = ephy_font_languages ();
 	n_font_languages = ephy_font_n_languages ();
 
@@ -1071,6 +1056,8 @@ mozilla_font_notifiers_init (void)
 static void
 mozilla_font_notifiers_shutdown (void)
 {
+	eel_gconf_monitor_remove ("/desktop/gnome/interface");
+
 	eel_gconf_notification_remove (desktop_font_data[0].cnxn_id);
 	eel_gconf_notification_remove (desktop_font_data[1].cnxn_id);
 	eel_gconf_notification_remove (minimum_font_size_data->cnxn_id);
@@ -1083,6 +1070,9 @@ mozilla_font_notifiers_shutdown (void)
 	g_strfreev (desktop_font_data[1].font_name_prefs);
 	g_strfreev (desktop_font_data[1].font_size_prefs);
 	g_strfreev (minimum_font_size_data->prefs);
+
+	g_free (desktop_font_data);
+	g_free (minimum_font_size_data);	
 }
 
 extern "C" gboolean
