@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.c,v 1.47 2006/02/13 23:02:09 chpe Exp $
+ *  $Id: ephy-gui.c,v 1.48 2006/04/02 20:08:14 chpe Exp $
  */
 
 #include "config.h"
@@ -391,31 +391,41 @@ ephy_gui_check_location_writable (GtkWidget *parent,
 }
 
 void
-ephy_gui_help (GtkWindow *parent,
-	       const char *file_name,
-               const char *link_id)
+ephy_gui_help_with_doc_id (GtkWindow *parent,
+			   const char *doc_id,
+			   const char *file_name,
+			   const char *link_id)
 {
-	GError *err = NULL;
+	GError *error = NULL;
 
-	gnome_help_display (file_name, link_id, &err);
+	gnome_help_display_with_doc_id (NULL, doc_id, file_name, link_id, &error);
 
-	if (err != NULL)
+	if (error != NULL)
 	{
 		GtkWidget *dialog;
+
 		dialog = gtk_message_dialog_new (parent,
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_OK,
-						 _("Could not display help: %s"), err->message);
-		g_signal_connect (G_OBJECT (dialog), "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-		gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+						 _("Could not display help: %s"),
+						 error->message);
+		g_error_free (error);
+
+		g_signal_connect (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy), NULL);
 		gtk_widget_show (dialog);
-		g_error_free (err);
 	}
 }
 
+void
+ephy_gui_help (GtkWindow *parent,
+	       const char *file_name,
+               const char *link_id)
+{
+	ephy_gui_help_with_doc_id (parent, NULL, file_name, link_id);
+}
+
 void
 ephy_gui_get_current_event (GdkEventType *otype,
 			    guint *ostate,
